#!/usr/bin/env python

import io

from draftjs_exporter import __version__

from setuptools import find_packages, setup

dependencies = {
    # Keep this in sync with the dependencies in tox.ini.
    'lxml': [
        'lxml>=4.2.0,<5',
    ],
    'html5lib': [
        'beautifulsoup4>=4.4.1,<5',
        'html5lib>=0.999,<=1.0.1',
    ],
    'docs': [],
}

# Development extras.
dependencies['testing'] = [
    # Required for running the tests.
    'tox>=2.3.1',

    # Benchmark dependencies.
    'markov_draftjs==0.1.1',
    'memory-profiler==0.47',
    'psutil==5.4.1',

    # For coverage and PEP8 linting.
    'coverage==5.0.1',
    'flake8>=3.2.0',
    'isort==4.2.5',
    'mypy==0.750',
] + dependencies['html5lib'] + dependencies['lxml']

with io.open('README.md', encoding='utf-8') as readme_file:
    long_description = readme_file.read()

setup(
    name='draftjs_exporter',
    version=__version__,
    description='Library to convert rich text from Draft.js raw ContentState to HTML',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='Springload',
    author_email='hello@springload.co.nz',
    url='https://github.com/springload/draftjs_exporter',
    packages=find_packages(exclude=['tests*']),
    include_package_data=True,
    license='MIT',
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Development Status :: 5 - Production/Stable',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Internet :: WWW/HTTP :: Site Management',
        'Topic :: Software Development :: Libraries :: Application Frameworks',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Text Editors :: Word Processors',
    ],
    package_data={
        'draftjs_exporter': ['py.typed'],
    },
    install_requires=[],
    extras_require=dependencies,
    zip_safe=False,
)
